@@ -1,76 +1,10 @@
-""" Callers of this module should strive to implement canonical log lines (when it makes sense):
-(source: https://stripe.com/blog/canonical-log-lines)
-canonical log lines: authoritative line for a particular request,
-- in the same vein that the IETF’s canonical link relation specifies an
-authoritative URL.
-
-**In addition to their normal log traces,**
-requests (or some other unit of work that’s executing) also emit
-ONE LONG LOG LINE at the end that
-pulls all its key telemetry into one place. i.e.,
-
-    ```
-    [2019-03-18 22:48:32.999] canonical-log-line
-    alloc_count=9123
-    auth_type=api_key
-    database_queries=34
-    duration=0.009
-    http_method=POST
-    http_path=/v1/charges
-    http_status=200
-    key_id=mk_123
-    permissions_used=account_write
-    rate_allowed=true
-    rate_quota=100
-    rate_remaining=99
-    request_id=req_123
-    team=acquiring
-    user_id=usr_123†
-    ```
-† uuid (aka guid) may be useful
-  i.e., user_id = uuid.uuid4()
-  See Also: [When are you truly forced to use UUID as part of the design?](https://stackoverflow.com/a/786541)
-This sample shows the kind of information that a canonical line might
-contain include:
-
-- HTTP request verb, path, and response status.
-- authenticated user and related information, like:
--- authentication method (API key, password)
--- ID of the API key they used.
-- rate limiters which allowed the request
--- related statistics (e.g. allotted quota and what portion remains)
-- Timing information like:
--- total request duration
--- time spent in database queries.
-- number of database queries issued
-- number of objects allocated by the VM.
-
-Canonical lines are an ergonomic feature.
-- By colocating everything that’s important to us, we make it accessible
-through queries that are easy for people to write, even under the duress of a
-production incident.
-- Because the underlying logging system doesn’t need to piece together
-multiple log lines at query time they’re also cheap for computers to retrieve
-and aggregate, which makes them fast to use.
-- The wide variety of information being logged provides almost limitless
-flexibility in what can be queried. This is especially valuable during the
-discovery phase of an incident where it’s understood that something’s wrong,
-but it’s still a mystery as to what.
-
-Getting insight into our rate limiting problem above becomes as simple as:
-- `canonical-log-line rate_allowed=false | stats count by user_id`
-
-Ideas:
-1. Decorators to emit function name and params?
-- con: verbose, perennially generating essentially debugging output
-"""
 import datetime
 import inspect
 import logging
 import logging.config
 import os
 from pathlib import Path
-from typing import List, Union
+from typing import Any, List, Union
 
 import git
 import orjson
@@ -106,11 +40,35 @@ def get_namespaced_module_name(__file__):
     return ".".join(namespaces)
 
 
-def get_logger():
-    prev_stack_frame = inspect.stack()[1]
-    caller_name = inspect.getmodule(prev_stack_frame[0]).__name__
-    if is_caller_main(caller_name):
-        caller_name = get_namespaced_module_name(prev_stack_frame.filename)
+def get_caller_name(prev_stack_frame):
+    deduced_calling_module = deduce_module(prev_stack_frame)
+    return (
+        deduced_calling_module.__name__
+        if deduced_calling_module
+        and not is_caller_main(deduced_calling_module.__name__)
+        else get_namespaced_module_name(prev_stack_frame.filename)
+    )
+
+
+def deduce_module(prev_stack_frame):
+    return inspect.getmodule(prev_stack_frame[0])
+
+
+def get_caller_name_from_frames(stack_frames):
+    prev_stack_frame = stack_frames[1]
+    return get_caller_name(prev_stack_frame)
+
+
+def get_logger() -> Any:
+    """
+    Convenience function that returns a logger
+
+    Returns: A proxy that creates a correctly configured logger bound to
+    the __name__ of the calling module
+
+    """
+    stack_frames = inspect.stack()
+    caller_name = get_caller_name_from_frames(stack_frames)
     if not structlog.is_configured():
         timestamper = structlog.processors.TimeStamper(fmt=DATETIME_FORMAT)
         set_logging_config(caller_name, timestamper)
@@ -135,9 +93,8 @@ def set_logging_config(module_name, timestamper):
             "plain": {
                 "()": structlog.stdlib.ProcessorFormatter,
                 "processor": structlog.processors.JSONRenderer(
-                    serializer=lambda *args, **kwargs: str(
-                        orjson.dumps(*args, **kwargs),
-                        "utf-8",
+                    serializer=lambda *args, **kwargs: (
+                        orjson.dumps(*args, **kwargs).decode()
                     ),
                     option=orjson.OPT_SORT_KEYS,
                 ),
@@ -226,9 +183,11 @@ def set_structlog_config(timestamper):
 class SentryBreadcrumbJsonProcessor(SentryJsonProcessor):
 
     """
-    Addresses: `SentryJsonProcessor breaks logging breadcrumbs #25`
-    (https://github.com/kiwicom/structlog-sentry/issues/25)
-    (source: https://github.com/kiwicom/structlog-sentry/issues/25#issuecomment-660292563)
+    Addresses: `SentryJsonProcessor breaks logging breadcrumbs #25`_
+    (source_)
+
+    .. _`SentryJsonProcessor breaks logging breadcrumbs #25`: https://github.com/kiwicom/structlog-sentry/issues/25
+    .. _`source`: https://github.com/kiwicom/structlog-sentry/issues/25#issuecomment-660292563
     """
 
     def __init__(  # pylint: disable=too-many-arguments
@@ -237,7 +196,9 @@ class SentryBreadcrumbJsonProcessor(SentryJsonProcessor):
         breadcrumb_level: int = logging.INFO,
         active: bool = True,
         as_extra: bool = True,
-        tag_keys: Union[List[str], str] = None,
+        tag_keys: Union[  # pylint: disable=unsubscriptable-object
+            List[str], str
+        ] = None,
     ) -> None:
         self.breadcrumb_level = breadcrumb_level
         super().__init__(
